package ch.epfl.ppo;

import java.util.HashSet;
import java.util.Set;

public final class Cell implements Subject {
    private final Set<Observer> observers = new HashSet<>();
    private int value = 0;

    public int value() {
        return value;
    }

    public void setValue(int newValue) {
        if (newValue != value) {
            value = newValue;
            notifyObservers();
        }
    }

    @Override
    public void addObserver(Observer o) {
        observers.add(o);
    }

    @Override
    public void removeObserver(Observer o) {
        observers.remove(o);
    }

    private void notifyObservers() {
        for (Observer o: observers)
            o.update(this);
    }
}
